@@ -1,11 +1,11 @@
-from anasymod.sim_ctrl.ctrlifc_datatypes import *
+from anasymod.sim_ctrl.datatypes import *
 from anasymod.enums import PortDir
 from typing import Union
 from anasymod.generators.codegen import CodeGenerator
 
-io_obj_types = DigitalCtrlInput, DigitalCtrlOutput, DigitalSignal, AnalogCtrlInput, AnalogCtrlOutput, AnalogSignal
-io_obj_types_union = Union[DigitalCtrlInput, DigitalCtrlOutput, DigitalSignal, AnalogCtrlInput, AnalogCtrlOutput, AnalogSignal]
-io_obj_types_str_union = Union[DigitalCtrlInput, DigitalCtrlOutput, DigitalSignal, AnalogCtrlInput, AnalogCtrlOutput, AnalogSignal, str]
+io_obj_types = DigitalCtrlInput, DigitalCtrlOutput, DigitalSignal, AnalogCtrlInput, AnalogCtrlOutput, AnalogSignal, AnalogProbe
+io_obj_types_union = Union[DigitalCtrlInput, DigitalCtrlOutput, DigitalSignal, AnalogCtrlInput, AnalogCtrlOutput, AnalogSignal, AnalogProbe]
+io_obj_types_str_union = Union[DigitalCtrlInput, DigitalCtrlOutput, DigitalSignal, AnalogCtrlInput, AnalogCtrlOutput, AnalogSignal, AnalogProbe, str]
 
 class GenAPI(CodeGenerator):
     """
@@ -88,11 +88,13 @@ class SVAPI(GenAPI):
         :param io_obj: io object
         """
 
-        if isinstance(io_obj, (AnalogCtrlInput, AnalogCtrlOutput, AnalogSignal)):
+        if isinstance(io_obj, AnalogProbe):
+            self.writeln(f"`MAKE_GENERIC_REAL({io_obj.name}, {io_obj.range}, {io_obj.width});")
+        elif isinstance(io_obj, AnalogSignal):
             self.writeln(f"`MAKE_REAL({io_obj.name}, {io_obj.range});")
-        elif isinstance(io_obj, (DigitalCtrlInput, DigitalCtrlOutput, DigitalSignal)):
+        elif isinstance(io_obj, DigitalSignal):
             if io_obj.width > 1:
-                self.writeln(f"logic [{str(io_obj.width)}  - 1:0] {io_obj.name};")
+                self.writeln(f'logic [{str(io_obj.width)}  - 1:0] {io_obj.name};')
             else:
                 self.writeln(f"logic {io_obj.name};")
 
@@ -104,25 +106,17 @@ class SVAPI(GenAPI):
         """
 
         if direction in [PortDir.IN]:
-            if isinstance(io_obj, AnalogSignal) and not isinstance(io_obj, (AnalogCtrlInput, AnalogCtrlOutput)):
+            if isinstance(io_obj, AnalogSignal):
                 return f"`INPUT_REAL({io_obj.name})"
             elif isinstance(io_obj, (DigitalCtrlInput, DigitalCtrlOutput, DigitalSignal)):
-                if io_obj.width > 1:
-                    return f"input wire logic [{str(io_obj.width)}  - 1:0] {io_obj.name}"
-                else:
-                    return f"input wire logic {io_obj.name}"
-            elif isinstance(io_obj, (AnalogCtrlInput, AnalogCtrlOutput)):
-                return f"input `DATA_TYPE_REAL(`LONG_WIDTH_REAL) {io_obj.name}"
+                width = f'[{str(io_obj.width - 1)}:0] ' if io_obj.width > 1 else ''
+                return f"input wire logic {'signed ' if io_obj.signed else ''}{width}{io_obj.name}"
         elif direction in [PortDir.OUT]:
-            if isinstance(io_obj, AnalogSignal)and not isinstance(io_obj, (AnalogCtrlInput, AnalogCtrlOutput)):
+            if isinstance(io_obj, AnalogSignal):
                 return f"`OUTPUT_REAL({io_obj.name})"
             elif isinstance(io_obj, (DigitalCtrlInput, DigitalCtrlOutput, DigitalSignal)):
-                if io_obj.width > 1:
-                    return f"output wire logic [{str(io_obj.width)}  - 1:0] {io_obj.name}"
-                else:
-                    return f"output wire logic {io_obj.name}"
-            elif isinstance(io_obj, (AnalogCtrlInput, AnalogCtrlOutput)):
-                return f"output `DATA_TYPE_REAL(`LONG_WIDTH_REAL) {io_obj.name}"
+                width = f'[{str(io_obj.width - 1)}:0] ' if io_obj.width > 1 else ''
+                return f"output wire logic {'signed ' if io_obj.signed else ''}{width}{io_obj.name}"
         else:
             raise Exception(f"No valid direction provided: {direction}")
 
@@ -152,7 +146,7 @@ class SVAPI(GenAPI):
             raise Exception(
                 f"Wrong number of io_objects provided in list, exactly two are requrend, provided were: {len(io_objs)}")
 
-    def assign_to(self, io_obj: io_obj_types_union, exp):
+    def assign_to(self, io_obj: io_obj_types_str_union, exp):
         """
         Assign 'exp' to signal 'io_obj.name'.
         NOTE: If the io_obj is of the AnalogSignal type, it is only possible to assign another signal of the same type
@@ -162,7 +156,7 @@ class SVAPI(GenAPI):
         :param exp: Expression to be assigned.
         """
 
-        if isinstance(io_obj, AnalogSignal) and not isinstance(io_obj, (AnalogCtrlInput, AnalogCtrlOutput)):
+        if isinstance(io_obj, AnalogSignal) and not isinstance(io_obj, (AnalogCtrlInput, AnalogCtrlOutput, AnalogProbe)):
             if isinstance(exp, AnalogSignal):
                 self.writeln(f"`ASSIGN_REAL({exp}, {io_obj.name});")
             if isinstance(exp, str):
@@ -174,10 +168,10 @@ class SVAPI(GenAPI):
                 except:
                     raise Exception(f"The provided expression is not supported for Analog Signals, only assignment of another"
                                     f"AnalogSignal object or a constant value is supported; given: '{exp}'")
-        elif isinstance(io_obj, (DigitalCtrlOutput, AnalogCtrlOutput)):
+        elif isinstance(io_obj, (DigitalSignal, AnalogCtrlInput, AnalogCtrlOutput, AnalogProbe)):
             self.writeln(f"assign {io_obj.name} = {exp};")
-        elif isinstance(io_obj, (DigitalCtrlInput, AnalogCtrlInput)):
-            self.writeln(f"assign {exp} = {io_obj.name};")
+        elif isinstance(io_obj, str):
+            self.writeln(f"assign {io_obj} = {exp};")
         else:
             raise Exception(f'Not supported signal type provided:{type(io_obj)}')
 
@@ -244,7 +238,7 @@ class ModuleInst():
                 raise Exception(f"Unsupported connection type was provided, supported types are. {io_obj_types_str_union}, "
                                 f"provided: {type(connection)}")
 
-        if isinstance(io_obj, (AnalogCtrlInput, AnalogCtrlOutput)):
+        if isinstance(io_obj, (AnalogSignal)):
             self.analog_inputs.append(io_obj)
         else:
             self.digital_inputs.append(io_obj)
@@ -268,7 +262,7 @@ class ModuleInst():
                 raise Exception(f"Unsupported connection type was provided, supported types "
                                 f"are. {io_obj_types_union}, provided: {type(connection)}")
 
-        if isinstance(io_obj, (AnalogCtrlInput, AnalogCtrlOutput)):
+        if isinstance(io_obj, (AnalogSignal)):
             self.analog_outputs.append(io_obj)
         else:
             self.digital_outputs.append(io_obj)
@@ -292,10 +286,10 @@ class ModuleInst():
         # Allow connections only of both signals are of type AnalogSignal, or both are of type DigitalSignal,
         # or signal is of type DigitalSignal and connecting signal is of type AnalogCtrlOutput/AnalogCtrlOutput; this is needed for
         # streaming Analog signals, or strings to account for constant values
-        if (isinstance(io_obj, AnalogSignal) and isinstance(io_obj_con, AnalogSignal)) or (
-                isinstance(io_obj, DigitalSignal) and isinstance(io_obj_con, DigitalSignal)) or (
-                isinstance(io_obj, DigitalSignal) and isinstance(io_obj_con, (AnalogCtrlInput, AnalogCtrlOutput)) or (
-                isinstance(io_obj_con, str))):
+        if (isinstance(io_obj, AnalogSignal) and isinstance(io_obj_con, AnalogSignal)) or \
+                (isinstance(io_obj, DigitalSignal) and isinstance(io_obj_con, DigitalSignal)) or \
+                (isinstance(io_obj, DigitalSignal) and isinstance(io_obj_con, (AnalogCtrlInput, AnalogCtrlOutput, AnalogProbe))) or \
+                (isinstance(io_obj_con, str)):
             self.connections.append([io_obj, io_obj_con])
         else:
             raise Exception(f"IO types of objects to be connected do not match:"
@@ -308,10 +302,6 @@ class ModuleInst():
 
         ### Check if module includes analog ports or parameters
         analog_ports = self.analog_inputs + self.analog_outputs
-        # Remove analog control signals as for those signals no parameters will be transmitted
-        for analog_port in analog_ports:
-            if isinstance(analog_port, (AnalogCtrlInput, AnalogCtrlOutput)):
-                analog_ports.remove(analog_port)
 
         if (analog_ports or self.parameters):
             self.api.writeln(f"module {self.name} #(")
@@ -356,7 +346,7 @@ class ModuleInst():
         analog_connections = []
         for connection in self.connections:
             # Remove analog control signals as for those signals no parameters will be transmitted
-            if isinstance(connection[0], AnalogSignal) and not isinstance(connection[0], (AnalogCtrlInput, AnalogCtrlOutput)):
+            if isinstance(connection[0], AnalogSignal):
                 analog_connections.append(connection)
 
         if (analog_connections or self.parameters):
@@ -380,7 +370,6 @@ class ModuleInst():
             self.api.indent()
             self.api.writeln(f"{self.name} {self.inst_name} (")
 
-
         ## Add port section
         self.api.indent()
         if self.connections:
@@ -389,4 +378,4 @@ class ModuleInst():
             self.api.writeln(self.api.gen_connection(self.connections[-1]))
 
         self.api.dedent()
-        self.api.writeln(f");")
+        self.api.writeln(f");")
\ No newline at end of file
